﻿using Steema.TeeChart;
using Steema.TeeChart.Drawing;
using System;
using System.Drawing;
using System.IO;

namespace ExportProblemsNETFramework
{
  internal static class Program
  {

    private const string ImagePath = @"C:\tmp\TestDotNet48\";
    private static readonly string ImageName = $"{ImagePath}Chart";
    /// <summary>
    /// The main entry point for the application.
    /// </summary>
    [STAThread]
    private static void Main()
    {
      Directory.CreateDirectory(ImagePath);

      TChart chart = new TChart();
      chart.Header.Brush.Color = Color.Aqua;
      chart.Header.Text = "The header";
      chart.Header.Transparent = false;
      SetFont(chart.Header.Font, "Arial", 20, false, Color.BlueViolet);

      chart.Series.Add(new Steema.TeeChart.Styles.Bar());
      chart.Series[0].Add(123, "A bar", Color.Coral);
      chart.Series[0].Add(456, "In PDF, the font is wrong whereas the label box is sized correctly.", Color.Green);
      chart.Series[0].Add(321, "Another bar", Color.Blue);
      SetFont(chart.Series[0].Marks.Font, "Times New Roman", 18, true, Color.Red);

      chart.Legend.Alignment = LegendAlignments.Top;
      SetFont(chart.Legend.Font, "Consolas", 14, true, Color.DarkOliveGreen);

      try
      {
        SaveAsPng(chart);
        SaveAsPdf(chart);
        SaveAsEps(chart); // throws NotImplementedException in .NET 5.0 Console !?!
      }
      catch (Exception e)
      {
        Console.WriteLine(e);
      }
    }

    private static void SetFont(ChartFont font, string family, int size, bool bold, Color color)
    {
      font.Name = family;
      font.Size = size;
      font.Bold = bold;
      font.Color = color;
    }

    private static void SaveAsPng(TChart chart)
    {
      Steema.TeeChart.Export.PNGFormat output = chart.Export.Image.PNG;
      output.Height = 600;
      output.Width = 800;
      output.Save($"{ImageName}.png");
    }

    private static void SaveAsPdf(TChart chart)
    {
      Steema.TeeChart.Export.PDFFormat output = chart.Export.Image.PDF;
      output.Height = 600;
      output.Width = 800;
      output.Save($"{ImageName}.pdf");
    }

    private static void SaveAsEps(TChart chart)
    {
      Steema.TeeChart.Export.EPSFormat output = chart.Export.Image.EPS;
      output.Height = 600;
      output.Width = 800;
      output.Save($"{ImageName}_for_pdf.eps");
    }
  }
}
